@@ -17,6 +17,7 @@ pub struct StorageData {
     //pub room_to_aliases: BTreeMap<RoomId, Vec<RoomAliasId>>,
     //pub alias_to_room: BTreeMap<RoomAliasId, RoomId>,
     pub joined_rooms: Vec<RoomId>,
+    pub room_id_to_cananoical_alias: BTreeMap<RoomId, RoomAliasId>,
     pub room_to_name: BTreeMap<RoomId, Box<RoomName>>,
 }
 
@@ -440,6 +441,7 @@ impl Client {
             //instructions.push(Instructions::AddRoom(room_id.clone()));
             if !self.data.joined_rooms.contains(room_id) {
                 self.data.joined_rooms.push(room_id.clone());
+                //self.data.room_to_name.insert(room_id.clone(), self.room_id_to_alias[room_id.clone()]);
                 self.room_list_updated = true;
             }
             for event in joined_room.state.events.clone() {
@@ -457,7 +459,7 @@ impl Client {
                                     .insert(alias.clone(), room_id.clone())
                                     .unwrap();
                             }
-                            if !self.data.room_to_aliases.contains_key(room_id) {
+                            if !self.data.room_to_alesiases.contains_key(room_id) {
                                 self.data
                                     .room_to_aliases
                                     .insert(room_id.clone(), vec![alias])
@@ -474,19 +476,28 @@ impl Client {
                             }
                             //instructions.push(Instructions::SaveRoomAlias(room_id.clone(), alias));
                         }
-                    } */
-                    //else if let ruma::events::AnySyncStateEvent::RoomCanonicalAlias
+                    }
+                    */
                     if let ruma::events::AnySyncStateEvent::RoomName(room_name_event) = ev.clone() {
                         if let Some(room_name) = room_name_event.content.name {
                             self.data.room_to_name.insert(room_id.clone(), room_name);
                         }
+                    } else if let ruma::events::AnySyncStateEvent::RoomCanonicalAlias(
+                        room_canonical_alias_event,
+                    ) = ev.clone()
+                    {
+                        if let Some(alias) = room_canonical_alias_event.content.alias {
+                            self.data
+                                .room_id_to_cananoical_alias
+                                .insert(room_id.clone(), alias);
+                        }
                     }
                 }
             }
             //if !event_args.starting {
             for message_info in joined_room.timeline.events.iter().filter_map(|m| {
-                if let ruma::events::AnySyncRoomEvent::Message(message_event) =
-                    m.deserialize_as().unwrap()
+                if let Ok(ruma::events::AnySyncRoomEvent::Message(message_event)) =
+                    m.deserialize_as()
                 {
                     if let ruma::events::AnySyncMessageEvent::RoomMessage(room_message) =
                         message_event
